@@ -54,7 +54,8 @@ $lang = array_merge($lang, array(
 	اعضا در زمان ثبت نام و همچنین از مرکز مدیریت کاربری می توانند این زمان را از کنترل پنل شخصی خودشان تعیین کنند.',
 
 	'WARNINGS_EXPIRE'	=> 'مدت زمان بقاي اخطار',
-	'WARNINGS_EXPIRE_EXPLAIN'	=> 'تعداد روزهایی که پیش از پایان یافتن اتوماتیک اخطار از پیشینه کاربر مورد نظر سپری خواهد شد.',
+	'WARNINGS_EXPIRE_EXPLAIN'	=> 'تعداد روزهایی که پیش از پایان یافتن اتوماتیک اخطار از پیشینه کاربر مورد نظر سپری خواهد شد.
+		برای ابدی شدن اخطارها، مقدار 0 را وارد کنید.',
 	'ACP_BOARD_FEATURES_EXPLAIN'	=> 'از اينجا شما مي توانيد فعال/غيرفعال کنيد چندي از سيماهاي بورد.',
 	'ALLOW_ATTACHMENTS'	=> 'فعال بودن پيوست ها',
 	'ALLOW_BIRTHDAYS'	=> 'فعال بودن متولدین',
@@ -517,7 +518,7 @@ $lang = array_merge($lang, array(
 	'DELETE_TIME_EXPLAIN'			=> 'مدت زمانی که کاربر می تواند پس از ایجاد یک پست جدید، آن را حذف کند.<br />برای غیر فعال کردن مقدار 0 را وارد کنید.',	//////////////////////////////////////////	
 		
 			'MIN_CHAR_LIMIT'				=> 'Minimum characters per post/message',
-	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'The minimum number of characters the user need to enter within a post/private message.',
+	'MIN_CHAR_LIMIT_EXPLAIN'		=> 'حداقل تعداد کاراکترهای لازم برای ارسال یک پست/پسام خصوصی. حداقل این مقدار 1 است.',
 				
 //////////////////////////////////////////
 
