@@ -300,7 +300,8 @@ $lang = array_merge($lang, array(
 // Index page
 $lang = array_merge($lang, array(
 	'ADMIN_INTRO'				=> '
-	
+
+
 <br />از حسن انتخاب شما در انتخاب phpBB آسان نصب Maghsad.com سپاسگزاريم.<br />
 <br /> در اين صفحه آمار بخش هاي مختلف انجمن شما و منوهاي مديريتي اصلي (در سمت راست و سربرگ ها) قرار گرفته است كه مي توانيد از آن ها براي مديريت انجمن بهره ببريد.<br />
 	همچنين مي توانيد از كتاب <strong>
@@ -308,7 +309,22 @@ $lang = array_merge($lang, array(
 	<span style="text-decoration: none">آموزش طراحي، ساخت و مديريت جوامع مجازي با استفاده 
 از phpBB 3</strong></span></a></font> (انتشارات كيان رايانه) به عنوان نخستين و تنها مرجع فارسي phpBB 3 
 براي آشنايي بيشتر با اين سيستم قدرتمند بهره مند شويد.
-<br /><br />	
+<br />
+<center>
+
+<table style="width: 100%" align="center">
+	<tr>
+		<td class="style1">
+		<a href="http://phpbb.maghsad.com/phpbb-learning/internet-very-simple-learning-t7726.html">
+		<img alt="آموزش اینترنت به زبان خیلی ساده" src="http://www.maghsad.com/ads/internet_ez_mini.jpg" longdesc="آموزش جامع، تصویری و گام به گام اینترنت"></a></td>
+		<td class="style1">
+
+
+<a href="http://phpbb.maghsad.com/phpbb-learning/phpbb-t3686.html">
+<img alt="کتاب راهنمای جامع تصویری phpBB" longdesc="آموزش phpBB" src="http://maghsad.com/ads/phpbb_3_book_mini.jpg"></a></td>
+	</tr>
+</table>
+</center><br />	
 
 برای شرکت در توسعه، <b>اصلاح هسته فارسی و فارسی ساز</b> 
 phpBB<a href="http://phpbb.maghsad.com/viewtopic.php?p=11810#p11810"> 
@@ -326,16 +342,37 @@ phpBB<a href="http://phpbb.maghsad.com/viewtopic.php?p=11810#p11810">
 <br />
 <strong>مشخصات هسته فارسی :</strong>
 			<br />	
-هسته فارسی  phpBB 3.0.9<br />
-نگارش هسته فارسي : 1.4.0 آزمایشی<br />
-نگارش آخرین اصلاحیه نصب شده هسته فارسی : دوشنبه 20 تیر 1390  <br />
+هسته فارسی  phpBB 3.0.10<br />
+نگارش هسته فارسي : 1.4.1 کریسمس<br />
+نگارش آخرین اصلاحیه نصب شده هسته فارسی : دوشنبه 12 اسفند 1390  <br />
 اعضای تیم توسعه phpBB فارسی:
 <a href="http://phpbb.maghsad.com/mafco-u1361/"><span lang="en-us">Mafco</span></a> ,<a href="http://phpbb.maghsad.com/asef-u2/">
-<span lang="en-us">Asef</span></a> .<br /><br />
+<span lang="en-us">Asef</span></a> .<br /><br /><strong>سایر امکانات و خدمات :</strong>
+			<br />
+<center>
+<table style="width: 100%">
+	<tr>
+		<td class="style1"><a href="http://maghsad.net">هاست رایگان</a></td>
+		<td class="style1">
+		<a href="http://maghsad.com/shop/index.php?route=product/category&amp;path=68_69">هاست ارزان</a></td>
+		<td class="style1"><a href="http://maghsad.com/host">هاست حرفه ای</a></td>
+	</tr>
+	<tr>
+		<td class="style1"><a href="http://phpbb.maghsad.com">پشتیبانی مشکلات و سوالات شما</a></td>
+		<td class="style1">
+		<a href="http://maghsad.com/shop/index.php?route=product/product&amp;product_id=57">بیمه سایت شما در مقابل هکرها!</a></td>
+		<td class="style1">
+		<a href="http://maghsad.com/shop/index.php?route=product/category&amp;path=61_65">قالب های حرفه ای و جدید <span lang="en-us">phpBB</span></a></td>
+	</tr>
+</table>
+</center>			
+			<br />
 	
 پشتيباني حقيقي phpBB فارسي را با ما تجربه كنيد :  <a href="http://www.phpBB.Maghsad.com">www.phpBB.Maghsad.com</a> ||  
 <a href="http://www.Maghsad.com">www.Maghsad.com</a>
 <br />	
+
+	
 ',
 	'ADMIN_LOG'					=> 'فعاليت هاي مدير',
 	'ADMIN_LOG_INDEX_EXPLAIN'	=> 'اين منو حاوي آخرين فعاليت هايي است که مدير سايت انجام داده است. در صورتي که تمايل به ديدن ليست کامل از فعاليت هاي مدير سايت داريد از لينک زير استفاده كنيد.  ',
@@ -347,6 +384,17 @@ phpBB<a href="http://phpbb.maghsad.com/viewtopic.php?p=11810#p11810">
 	'DATABASE_SERVER_INFO'	=> 'سرور بانک اطلاعات',
 	'DATABASE_SIZE'			=> 'حجم بانک اطلاعاتي',
 
+	// Enviroment configuration checks, mbstring related
+	'ERROR_MBSTRING_FUNC_OVERLOAD'					=> 'Function overloading is improperly configured',
+	'ERROR_MBSTRING_FUNC_OVERLOAD_EXPLAIN'			=> '<var>mbstring.func_overload</var> must be set to either 0 or 4. You can check the current value on the <samp>PHP information</samp> page.',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION'			=> 'Transparent character encoding is improperly configured',
+	'ERROR_MBSTRING_ENCODING_TRANSLATION_EXPLAIN'	=> '<var>mbstring.encoding_translation</var> must be set to 0. You can check the current value on the <samp>PHP information</samp> page.',
+	'ERROR_MBSTRING_HTTP_INPUT'						=> 'HTTP input character conversion is improperly configured',
+	'ERROR_MBSTRING_HTTP_INPUT_EXPLAIN'				=> '<var>mbstring.http_input</var> must be set to <samp>pass</samp>. You can check the current value on the <samp>PHP information</samp> page.',
+	'ERROR_MBSTRING_HTTP_OUTPUT'					=> 'HTTP output character conversion is improperly configured',
+	'ERROR_MBSTRING_HTTP_OUTPUT_EXPLAIN'			=> '<var>mbstring.http_output</var> must be set to <samp>pass</samp>. You can check the current value on the <samp>PHP information</samp> page.',
+
+
 	'FILES_PER_DAY'		=> 'پیوست در هر روز',
 	'FORUM_STATS'		=> 'آمار انجمن',
 
