@@ -181,6 +181,7 @@ $lang = array_merge($lang, array(
 	'CURRENT_IMAGE'				=> 'تصوير کنوني',
 	'CURRENT_PASSWORD'			=> 'کلمه عبور کنوني',
 	'CURRENT_PASSWORD_EXPLAIN'	=> 'شما بايد کلمه عبور کنوني خود را وارد کنيد تا کلمه عبور جديد شما تاييد گردد.',
+		'CUR_PASSWORD_EMPTY'		=> 'پسورد فعلی را وارد نکردید.',
 	'CUR_PASSWORD_ERROR'		=> 'کلمه عبور کنوني وارد شده اشتباه مي باشد.',
 	'CUSTOM_DATEFORMAT'			=> 'سفارشی ...',
 
@@ -277,6 +278,7 @@ $lang = array_merge($lang, array(
 	'INVALID_USER_BIRTHDAY'			=> 'تاريخ تولد وارد شده صحيح نيست.',
 	'INVALID_CHARS_USERNAME'	=> 'The username contains forbidden characters.',
 	'INVALID_CHARS_NEW_PASSWORD'=> 'The password does not contain the required characters.',
+			'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'شما پسورد را مجددا وارد نکردید.',
 	'ITEMS_REQUIRED'			=> 'The items marked with * are required profile fields and need to be filled out.',
 
 	'JOIN_SELECTED'				=> 'Join selected',
@@ -309,6 +311,7 @@ $lang = array_merge($lang, array(
 	'MOVE_PM_ERROR'					=> 'An error occurred while moving the messages to the new folder, only %1d from %2d messages were moved.',
 	'MOVE_TO_FOLDER'				=> 'انتقال به پوشه',
 	'MOVE_UP'						=> 'برو بالا',
+	'NEW_EMAIL_CONFIRM_EMPTY'		=> 'آدرس Email را مجددا وارد نکردید.',
 
 	'NEW_EMAIL_ERROR'				=> 'ايميل هاي وارد شده جفت نمي باشند.',
 	'NEW_FOLDER_NAME'				=> 'نام پوشه جديد',
